@@ -41,24 +41,13 @@ def model_deployment(project_id,model_id,token):
         }
 
         deployment_url = f"{base_url}/training/deployment"
-        model_select = f"{base_url}training/model-selector"
         access_token = 'Bearer '+ token
         headers = {"Authorization": access_token}
         # Send the POST request
         response = requests.post(deployment_url, data=data, headers=headers)
-        #
-        data2 = {
-            "deployment_id": response.json()['deployment_id'],
-            "model_id":model_id
-        }
-        #updating ds file folder with model id for running visualizer directly 
-        requests.post(model_select, data=data2, headers=headers)
         return response.json()
     except:
         return "manual model has no deployment"
-    
-
-
 
 
 def get_training_result(project_id,token):
@@ -160,3 +149,19 @@ def update_deployment(deployment_id,model_id,token):
     }
     response = requests.put(url,data=data,headers=headers)
     return json_check(response)
+
+
+def retrain_model(token, data):
+    url = f"{base_url}/training/model-retrain"
+    access_token = 'Bearer '+ token
+    headers = {"Authorization": access_token}
+    response = requests.post(url, data=data, headers=headers)
+    try:
+        response_data = response.json()
+    except:
+        response_data = None
+
+    if response_data:
+        return response_data
+    else:
+        return "Something went wrong on service"
