@@ -15,7 +15,7 @@ def aicloud_model_monitoring(token,deployment_id,file_path,modelling_mode):
         }
         url = f"{base_url}/training/aipilot/monitor-model"
         # Get The Monitor Graph Of The Deployed Model
-        access_token = 'Bearer '+ {token}
+        access_token = 'Bearer '+ token
         headers = {"Authorization": access_token}
         uploaded_filename, content = read_file(file_path)
         files = {'file': (uploaded_filename, content)}
@@ -35,7 +35,7 @@ def aicloud_model_monitoring(token,deployment_id,file_path,modelling_mode):
         }
         url = f"{base_url}/training/comprehensive/monitor-model"
         # Get The Monitor Graph Of The Deployed Model
-        access_token = 'Bearer '+ {token}
+        access_token = 'Bearer '+ token
         headers = {"Authorization": access_token}
         uploaded_filename, content = read_file(file_path)
         files = {'file': (uploaded_filename, content)}
@@ -54,7 +54,7 @@ def aipilot_model_monitoring(token,deployment_id,res_type,file_path,mode):
     }
     url = f"{base_url}/training/aipilot/monitor-model"
     # Get The Monitor Graph Of The Deployed Model
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     uploaded_filename, content = read_file(file_path)
     files = {'file': (uploaded_filename, content)}
@@ -75,7 +75,7 @@ def comprehensive_model_monitoring(token,deployment_id,res_type,file_path,mode):
     }
     url = f"{base_url}/training/comprehensive/monitor-model"
     # Get The Monitor Graph Of The Deployed Model
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     uploaded_filename, content = read_file(file_path)
     files = {'file': (uploaded_filename, content)}
