@@ -32,7 +32,7 @@ def roc_plot(deployment_id,res_type,token):
     "res_type" : res_type 
     }
     url = f"{base_url}/plot/roc"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.post(url, data=data,headers=headers)
     if data.get('res_type') == 'image':
@@ -46,7 +46,7 @@ def advanced_lift_chart(deployment_id,res_type,token):
     "res_type" : res_type 
     }
     url = f"{base_url}/plot/advanced-lift-chart"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     # Send the POST request
     response = requests.post(url, data=data,headers=headers)
@@ -61,7 +61,7 @@ def advanced_feature_impact(deployment_id,res_type,token):
     "res_type" : res_type 
     }
     url = f"{base_url}/plot/advanced-feature-impact"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     # Send the POST request
     response = requests.post(url, data=data,headers=headers)
@@ -76,7 +76,7 @@ def partial_dependency(deployment_id,res_type,token):
     "res_type" : res_type 
     }
     url = f"{base_url}/plot/partial-dependency"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     # Send the POST request
     response = requests.post(url, data=data,headers=headers)
@@ -87,13 +87,14 @@ def partial_dependency(deployment_id,res_type,token):
 
 
 
-def residual(deployment_id,res_type,client_token):
+def residual(deployment_id,res_type,token):
     data = {
     "deployment_id": deployment_id,
     "res_type" : res_type 
     }
     url = f"{base_url}/plot/residual"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ token
+    headers = {"Authorization": access_token}
     # Send the POST request
     response = requests.post(url, data=data,headers=headers)
     if data.get('res_type') == 'image':
@@ -102,13 +103,14 @@ def residual(deployment_id,res_type,client_token):
 
 
 
-def predict_vs_actual(deployment_id,res_type,client_token):
+def predict_vs_actual(deployment_id,res_type,token):
     data = {
     "deployment_id": deployment_id,
     "res_type" : res_type 
     }
     url = f"{base_url}/plot/predict-vs-actual"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ token
+    headers = {"Authorization": access_token}
     # Send the POST request
     response = requests.post(url, data=data,headers=headers)
     if data.get('res_type') == 'image':
@@ -116,13 +118,14 @@ def predict_vs_actual(deployment_id,res_type,client_token):
     return response.json()
 
 
-def word_cloud(deployment_id,res_type,client_token):
+def word_cloud(deployment_id,res_type,token):
     data = {
     "deployment_id": deployment_id,
     "res_type" : res_type 
     }
     url = f"{base_url}/plot/wordcloud"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ token
+    headers = {"Authorization": access_token}
     # Send the POST request
     response = requests.post(url, data=data,headers=headers)
     if data.get('res_type') == 'image':
@@ -130,13 +133,14 @@ def word_cloud(deployment_id,res_type,client_token):
     return response.json()
 
 
-def confusion_matrix(deployment_id,res_type,client_token):
+def confusion_matrix(deployment_id,res_type,token):
     data = {
     "deployment_id": deployment_id,
     "res_type" : res_type 
     }
     url = f"{base_url}/plot/confusion-matrix"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ token
+    headers = {"Authorization": access_token}
     # Send the POST request
     response = requests.post(url, data=data,headers=headers)
     if data.get('res_type') == 'image':
@@ -144,21 +148,34 @@ def confusion_matrix(deployment_id,res_type,client_token):
     return response.json()
 
 
-def get_allColumns(deployment_id,client_token):
+def get_allColumns(deployment_id,token):
     url = f"{base_url}/plot/dataset-columns//{deployment_id}"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ token
+    headers = {"Authorization": access_token}
     response = requests.get(url,headers=headers)
     return response.json()
 
-def prediction_distribution(deployment_id,res_type,client_token):
+def prediction_distribution(deployment_id,res_type,token):
     data = {
     "deployment_id": deployment_id,
     "res_type" : res_type 
     }
     url = f"{base_url}/plot/prediction-distribution"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ token
+    headers = {"Authorization": access_token}
     # Send the POST request
     response = requests.post(url, data=data,headers=headers)
     if data.get('res_type') == 'image':
         return response.content
+    return response.json()
+
+
+def blueprint_plot(deployment_id,token):
+    data = {
+    "deployment_id": deployment_id,
+    }
+    url = f"{base_url}/plot/blueprint-plot"
+    access_token = 'Bearer '+ token
+    headers = {"Authorization": access_token}
+    response = requests.post(url, data=data,headers=headers)
     return response.json()
\ No newline at end of file
