@@ -11,7 +11,7 @@ def read_file(file_path):
 def make_prediction(file_path, endpoint, token, data):
     uploaded_prediction_filename, content = read_file(file_path)
     url = f"{base_url}/prediction/{endpoint}" if endpoint else f"{base_url}/prediction/"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     files = {'prediction_file': (uploaded_prediction_filename, content)}
     try:
@@ -52,7 +52,7 @@ def comprehensive_prediction(file_path, token, deployment_id):
 
 def get_prediction_result(deployment_or_project_id, token, mode):
     url = ""
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
 
     if mode.lower() == "quick":
