@@ -3,7 +3,7 @@ from ..config import base_url, api_token
 
 def get_prediction_status(deployment_or_project_id, token, mode):
     url = ""
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     url = f"{base_url}/prediction/check-prediction-status/{deployment_or_project_id}"
 
@@ -17,7 +17,7 @@ def get_prediction_status(deployment_or_project_id, token, mode):
 
 def get_training_status(project_id,token):
     url = f"{base_url}/training/check-status/{project_id}"
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.get(url,headers=headers)
     return response.json()
\ No newline at end of file
